@@ -1,5 +1,8 @@
 import time
-from email.Utils import formatdate
+try:
+    from email.utils import formatdate
+except ImportError:
+    from email.Utils import formatdate
 from AccessControl.PermissionRole import rolesForPermissionOn
 from zope.lifecycleevent import IObjectModifiedEvent
 from Products.CMFCore.interfaces import IActionSucceededEvent
@@ -25,5 +28,5 @@ def triggerSiteimproveRecheck(obj, event):
             request = getRequest()
             expiration_seconds = time.time() + (1 * 60 * 60)  # 1 hour from now
             expires = formatdate(expiration_seconds, usegmt=True)
-            request.response.setCookie("SI-Published", True, path='/',
+            request.response.setCookie("SI-Published", 'True', path='/',
                                        expires=expires)
